@@ -1,12 +1,12 @@
 from __future__ import annotations
 from datetime import datetime
-import paths
+from . import paths
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.chrome.options import Options
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.common.exceptions import WebDriverException
-from variables import *
+from .variables import *
 
 
 class User:
@@ -258,7 +258,8 @@ class Registro(Finestra):
     status_str: dict[str, int] = {
         'p': RegistroStatus.PRESENTE,
         'a': RegistroStatus.ASSENTE,
-        'al': RegistroStatus.ASSENTE
+        'al': RegistroStatus.ASSENTE,
+        'ap': RegistroStatus.ASSENTE,
     }
 
     def status_from_str(self, status: str) -> int:
@@ -280,9 +281,19 @@ class Registro(Finestra):
         self._select_date(date)
         # Get the status from the date
         if (not hour): # They want the status of the day
-            status: WebElement = self.driver.find_element(By.XPATH, paths.status_p)
-            status_: str = status.text
-            return self.status_from_str(status_.lower())
+            return self.get_day_status(date)
         else: # They want the status of a specific hour
-            ... # TODO: Implement this
-            # The problem is caused by the fact that some hours come with groups of two or three
\ No newline at end of file
+            x = 0
+            tbody: WebElement = self.driver.find_element(By.XPATH, paths.lezioni_tbody)
+            trs: list[WebElement] = tbody.find_elements(By.TAG_NAME, "tr")
+            for tr in trs:
+                if ("display:none" in tr.get_attribute("style")):
+                    break
+                td: WebElement = tr.find_elements(By.TAG_NAME, "td")[2]
+                if (int(td.text[0]) > hour): # 1^ (2)
+                    break
+                x += 1
+            mainrow: WebElement = self.driver.find_element(By.XPATH, paths.lezioni_mainrow)
+            td: WebElement = mainrow.find_elements(By.TAG_NAME, "td")[x+9]
+            div: WebElement = td.find_elements(By.TAG_NAME, "div")[1]
+            return RegistroStatus.from_str(div.text)
\ No newline at end of file
